{% extends "base.html" %}
{% load static %}
{% load i18n %}
{% block content %}
<p><a class="btn btn-default" href="{% url 'pyfb-endpoint:pyfb_endpoint_codec_list' %}">Codec Listing</a></p>
<table class="table">
<tr><td>name</td><td>{{ object.name }}</td></tr>
<tr><td>created</td><td>{{ object.created }}</td></tr>
<tr><td>modified</td><td>{{ object.modified }}</td></tr>
<tr><td>number</td><td>{{ object.number }}</td></tr>
<tr><td>ptime</td><td>{{ object.ptime }}</td></tr>
<tr><td>stereo</td><td>{{ object.stereo }}</td></tr>
<tr><td>rfc_name</td><td>{{ object.rfc_name }}</td></tr>
<tr><td>description</td><td>{{ object.description }}</td></tr>
</table>
<a class="btn btn-primary" href="{{object.get_update_url}}">Edit Codec</a>

{% endblock %}
