{% extends "base.html" %}
{% load static %}
{% load i18n %}
{% block content %}
<p><a class="btn btn-default" href="{% url 'pyfb-endpoint:pyfb_endpoint_codec_list' %}">Codec Listing</a></p>
<table class="table">
<tr>
<td>ID</td><td>Link</td>
    <td>name</td>
    <td>created</td>
    <td>modified</td>
    <td>number</td>
    <td>ptime</td>
    <td>stereo</td>
    <td>rfc_name</td>
    <td>description</td>
</tr>
{% for object in object_list %}
<tr>
    <td>{{object.pk}}</td>
    <td><a href="{{object.get_absolute_url}}">{{object}}</a></td>
    <td>{{ object.name }}</td>
    <td>{{ object.created }}</td>
    <td>{{ object.modified }}</td>
    <td>{{ object.number }}</td>
    <td>{{ object.ptime }}</td>
    <td>{{ object.stereo }}</td>
    <td>{{ object.rfc_name }}</td>
    <td>{{ object.description }}</td>
</tr>
{% endfor %}
</table><a class="btn btn-primary" href="{% url 'pyfb-endpoint:pyfb_endpoint_codec_create' %}">Create new Codec</a>
{% endblock %}
