# Generated by Django 2.1.8 on 2019-05-23 17:17

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('pyfb_kamailio', '0009_auto_20190523_1647'),
        ('pyfb_endpoint', '0009_auto_20190410_1549'),
    ]

    operations = [
        migrations.AddField(
            model_name='customerendpoint',
            name='domain',
            field=models.ForeignKey(default=1, on_delete=django.db.models.deletion.CASCADE, related_name='domain_edp', to='pyfb_kamailio.Domain', verbose_name='SIP Domain'),
            preserve_default=False,
        ),
    ]
