# Generated by Django 2.2.11 on 2020-03-21 15:38

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('pyfb_endpoint', '0014_auto_20190710_1456'),
    ]

    operations = [
        migrations.AddField(
            model_name='providerendpoint',
            name='add_plus_in_caller',
            field=models.BooleanField(default=False, help_text='Add a + in front of the callerid number for outbound calls via this gateway.', verbose_name='add + in caller ID'),
        ),
    ]
