{% extends "base.html" %}
{% load static %}
{% load i18n %}
{% block content %}
<p><a class="btn btn-default" href="{% url 'pyfb-endpoint:pyfb_endpoint_providerendpoint_list' %}">ProviderEndpoint Listing</a></p>
<table class="table">
<tr><td>name</td><td>{{ object.name }}</td></tr>
<tr><td>created</td><td>{{ object.created }}</td></tr>
<tr><td>modified</td><td>{{ object.modified }}</td></tr>
<tr><td>max_calls</td><td>{{ object.max_calls }}</td></tr>
<tr><td>enabled</td><td>{{ object.enabled }}</td></tr>
<tr><td>prefix</td><td>{{ object.prefix }}</td></tr>
<tr><td>suffix</td><td>{{ object.suffix }}</td></tr>
<tr><td>username</td><td>{{ object.username }}</td></tr>
<tr><td>password</td><td>{{ object.password }}</td></tr>
<tr><td>register</td><td>{{ object.register }}</td></tr>
<tr><td>sip_proxy</td><td>{{ object.sip_proxy }}</td></tr>
<tr><td>sip_transport</td><td>{{ object.sip_transport }}</td></tr>
<tr><td>sip_port</td><td>{{ object.sip_port }}</td></tr>
<tr><td>realm</td><td>{{ object.realm }}</td></tr>
<tr><td>from_domain</td><td>{{ object.from_domain }}</td></tr>
<tr><td>expire_seconds</td><td>{{ object.expire_seconds }}</td></tr>
<tr><td>retry_seconds</td><td>{{ object.retry_seconds }}</td></tr>
<tr><td>caller_id_in_from</td><td>{{ object.caller_id_in_from }}</td></tr>
<tr><td>add_plus_in_caller</td><td>{{ object.add_plus_in_caller }}</td></tr>
<tr><td>pid</td><td>{{ object.pid }}</td></tr>
<tr><td>pai</td><td>{{ object.pai }}</td></tr>
<tr><td>calls_per_second</td><td>{{ object.calls_per_second }}</td></tr>
<tr><td>rtp_transport</td><td>{{ object.rtp_transport }}</td></tr>
<tr><td>rtp_tos</td><td>{{ object.rtp_tos }}</td></tr>
</table>
<a class="btn btn-primary" href="{{object.get_update_url}}">Edit ProviderEndpoint</a>

{% endblock %}
