# Generated by Django 2.1.4 on 2018-12-19 14:02

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('pyfb_endpoint', '0003_auto_20181219_1354'),
    ]

    operations = [
        migrations.AlterField(
            model_name='customerendpoint',
            name='codec_list',
            field=models.ManyToManyField(blank=True, help_text='if NULL, all available codecs are allowed', related_name='codecs_c', to='pyfb_endpoint.Codec'),
        ),
        migrations.AlterField(
            model_name='providerendpoint',
            name='codec_list',
            field=models.ManyToManyField(blank=True, help_text='if NULL, all available codecs are allowed', related_name='codecs_p', to='pyfb_endpoint.Codec'),
        ),
    ]
