# Generated by Django 2.1.4 on 2018-12-18 17:00

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('pyfb_endpoint', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='customerendpoint',
            name='calls_per_second',
            field=models.PositiveIntegerField(default=10, help_text='maximum calls per second allowed for this customer endpoint.', verbose_name='max calls per second'),
        ),
        migrations.AlterField(
            model_name='customerendpoint',
            name='max_calls',
            field=models.PositiveIntegerField(default=1, help_text='max simultaneous calls allowed for this customer account.', verbose_name='max calls'),
        ),
    ]
